==> nextcloud-28.0.8.tgz: nextcloud/apps/files_reminders/l10n/de.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Dateierinnerungen",
    "Reminder for {name}" : "Erinnerung für {name}",
    "View file" : "Datei anzeigen",
    "View folder" : "Ordner anzeigen",
    "Set file reminders" : "Dateierinnerungen setzen",
    "**📣 File reminders**\n\nSet file reminders." : "**📣 Dateierinnerungen**\n\nSetze Dateierinnerungen.",
    "We will remind you of this file" : "Du wirst an diese Datei erinnert",
    "Please choose a valid date & time" : "Bitte gültiges Datum und Uhrzeit wählen",
    "Cancel" : "Abbrechen",
    "Clear reminder" : "Erinnerung löschen",
    "Set reminder" : "Erinnerung erstellen",
    "Set reminder for \"{fileName}\"" : "Erinnerung für \"{fileName}\" setzen",
    "Set reminder at custom date & time" : "Erinnerung für benutzerdefinierten Zeitpunkt und Tag erstellen",
    "Reminder set for \"{fileName}\"" : "Erinnerung für \"{fileName}\" gesetzt",
    "Failed to set reminder" : "Fehler beim Setzen der Erinnerung",
    "Failed to clear reminder" : "Fehler beim Löschen der Erinnerung",
    "Set custom reminder" : "Benutzerdefinierte Erinnerung erstellen",
    "Later today" : "Später heute",
    "Set reminder for later today" : "Erinnerung für nachher erstellen",
    "Tomorrow" : "Morgen",
    "Set reminder for tomorrow" : "Erinnerung für morgen erstellen",
    "This weekend" : "Dieses Wochenende",
    "Set reminder for this weekend" : "Erinnerung für dieses Wochenende erstellen",
    "Next week" : "Nächste Woche",
    "Set reminder for next week" : "Erinnerung für nächste Woche erstellen",
    "Back" : "Zurück",
    "Reminder cleared" : "Erinnerung gelöscht",
    "Failed to load reminder" : "Fehler beim Laden der Erinnerung"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-28.0.14.tgz: nextcloud/apps/files_reminders/l10n/de.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Dateierinnerungen",
    "Reminder for {name}" : "Erinnerung für {name}",
    "View file" : "Datei anzeigen",
    "View folder" : "Ordner anzeigen",
    "Set file reminders" : "Dateierinnerungen setzen",
    "We will remind you of this file" : "Du wirst an diese Datei erinnert",
    "Please choose a valid date & time" : "Bitte gültiges Datum und Uhrzeit wählen",
    "Cancel" : "Abbrechen",
    "Clear reminder" : "Erinnerung löschen",
    "Set reminder" : "Erinnerung erstellen",
    "Set reminder for \"{fileName}\"" : "Erinnerung für \"{fileName}\" setzen",
    "Set reminder at custom date & time" : "Erinnerung für benutzerdefinierten Zeitpunkt und Tag erstellen",
    "Reminder set for \"{fileName}\"" : "Erinnerung für \"{fileName}\" gesetzt",
    "Failed to set reminder" : "Fehler beim Setzen der Erinnerung",
    "Reminder cleared for \"{fileName}\"" : "Erinnerung für \"{fileName}\" gelöscht",
    "Failed to clear reminder" : "Fehler beim Löschen der Erinnerung",
    "Reminder set" : "Erinnerung gesetzt",
    "Set custom reminder" : "Benutzerdefinierte Erinnerung erstellen",
    "Later today" : "Später heute",
    "Set reminder for later today" : "Erinnerung für nachher erstellen",
    "Tomorrow" : "Morgen",
    "Set reminder for tomorrow" : "Erinnerung für morgen erstellen",
    "This weekend" : "Dieses Wochenende",
    "Set reminder for this weekend" : "Erinnerung für dieses Wochenende erstellen",
    "Next week" : "Nächste Woche",
    "Set reminder for next week" : "Erinnerung für nächste Woche erstellen",
    "**📣 File reminders**\n\nSet file reminders." : "**📣 Dateierinnerungen**\n\nSetze Dateierinnerungen."
},
"nplurals=2; plural=(n != 1);");
